# Calculate and plot the proportion of (1) lineage cells over the total cells, (2) immune cell subsets over the total immune
# Author: Selena Ferrian
# Date: 2/1/21

library(RColorBrewer)
library(ggplot2)
#https://www.rapidtables.com/web/color/RGB_Color.html#color-table

#other cell #FFFFFF
#Vim #CCCCCC
#CD31 cell #666666
#SMA cell #333333
#PANCK cell #000000

#CD209 #CCFF33
#CD68 #FFCC66
#MAST CELL #663300
#CD45 other #FFFFFF
#CD3 other #003366
#CD4 #3399FF
#CD8 #66CCFF
#CD20 #00FFCC
#CD56 #FF3300
#CD14 #FF9933


#Load dataset
d <- read.csv("Count&Freq-PerPoint.csv", TRUE, sep = ",")


##### GI case ######

GI<-droplevels(d[d$GI.cntrl == 'disease',])

#Subset lineage cells
GI_CD31<-droplevels(GI[GI$Cell_Type == 'CD31_cell',])
GI_SMA<-droplevels(GI[GI$Cell_Type == 'SMA_cell',])
GI_Vim<-droplevels(GI[GI$Cell_Type == 'Vim_cell',])
GI_PanCK<-droplevels(GI[GI$Cell_Type == 'PanCK_cell',])
GI_Immune<-droplevels(GI[GI$Cell_Type == 'Immune',])
GI_Other<-droplevels(GI[GI$Cell_Type == 'Other',])
GI_Lin <- rbind(GI_CD31, GI_SMA, GI_Vim, GI_PanCK, GI_Immune, GI_Other)
dim(GI_Lin)

#Subset immune cells
GI_CD3<-droplevels(GI[GI$Cell_Type == 'CD3_cell',])
GI_CD4<-droplevels(GI[GI$Cell_Type == 'CD4_cell',])
GI_CD8<-droplevels(GI[GI$Cell_Type == 'CD8_cell',])
GI_CD20<-droplevels(GI[GI$Cell_Type == 'CD20_cell',])
GI_CD14<-droplevels(GI[GI$Cell_Type == 'CD14_cell',])
GI_CD68<-droplevels(GI[GI$Cell_Type == 'CD68_cell',])
GI_CD209<-droplevels(GI[GI$Cell_Type == 'CD209_cell',])
GI_CD45<-droplevels(GI[GI$Cell_Type == 'CD45_other',])
GI_CD56<-droplevels(GI[GI$Cell_Type == 'CD56_cell',])
GI_Mast<-droplevels(GI[GI$Cell_Type == 'Mast_cell',])
GI_Im <- rbind(GI_CD3, GI_CD4, GI_CD8, GI_CD20, GI_CD14, GI_CD68, GI_CD209, GI_CD45, GI_CD56, GI_Mast)
dim(GI_Im)


#Plot LINEAGE pie
GI_Lin <- aggregate(GI_Lin$Count, 
                  by=list(GI_Lin$Cell_Type), FUN=sum)
print(GI_Lin)
cols = c("#7B858A", "#FF00FF", "#F5F5F5", "#000000", "#3D4242","#DCDCDC") 
pie(GI_Lin$x, GI_Lin$Group.1, col = cols, border = "white", lty = 1,
    clockwise = TRUE, main = "Total cell")
dev.off()

#Plot IMMUNE pie
GI_Im <- aggregate(GI_Im$Count, 
                      by=list(GI_Im$Cell_Type), FUN=sum)
print(GI_Im)
cols = c("#FF8C00", "#00FF7F", "#ADFF2F", "#003366", "#1E90FF", "#FFFFFF", "#FF4500", "#FFCC66", "#66CCFF", "#663300") 
pie(GI_Im$x, GI_Im$Group.1, col = cols, border = "white", lty = 1, 
    clockwise = TRUE, main = "Total cell")



#-------------------------------------
##### HEALTHY ######

Cnt<-droplevels(d[d$GI.cntrl == 'healthy',])

#Subset lineage cells
Cnt_CD31<-droplevels(Cnt[Cnt$Cell_Type == 'CD31_cell',])
Cnt_SMA<-droplevels(Cnt[Cnt$Cell_Type == 'SMA_cell',])
Cnt_Vim<-droplevels(Cnt[Cnt$Cell_Type == 'Vim_cell',])
Cnt_PanCK<-droplevels(Cnt[Cnt$Cell_Type == 'NaKATPase_cell',])
Cnt_Immune<-droplevels(Cnt[Cnt$Cell_Type == 'Immune',])
Cnt_Other<-droplevels(Cnt[Cnt$Cell_Type == 'Other',])
Cnt_Lin <- rbind(Cnt_CD31, Cnt_SMA, Cnt_Vim, Cnt_PanCK, Cnt_Immune, Cnt_Other)
dim(Cnt_Lin)

#Subset immune cells
Cnt_CD3<-droplevels(Cnt[Cnt$Cell_Type == 'CD3_cell',])
Cnt_CD4<-droplevels(Cnt[Cnt$Cell_Type == 'CD4_cell',])
Cnt_CD8<-droplevels(Cnt[Cnt$Cell_Type == 'CD8_cell',])
Cnt_CD20<-droplevels(Cnt[Cnt$Cell_Type == 'CD20_cell',])
Cnt_CD14<-droplevels(Cnt[Cnt$Cell_Type == 'CD14_cell',])
Cnt_CD68<-droplevels(Cnt[Cnt$Cell_Type == 'CD68_cell',])
Cnt_CD209<-droplevels(Cnt[Cnt$Cell_Type == 'CD209_cell',])
Cnt_CD45<-droplevels(Cnt[Cnt$Cell_Type == 'CD45_other',])
Cnt_CD56<-droplevels(Cnt[Cnt$Cell_Type == 'CD56_cell',])
Cnt_Mast<-droplevels(Cnt[Cnt$Cell_Type == 'Mast_cell',])
Cnt_Im <- rbind(Cnt_CD3, Cnt_CD4, Cnt_CD8, Cnt_CD20, Cnt_CD14, Cnt_CD68, Cnt_CD209, Cnt_CD45, Cnt_CD56, Cnt_Mast)
dim(Cnt_Im)

#Plot LINEAGE pie
Cnt_Lin <- aggregate(Cnt_Lin$Count, 
                    by=list(Cnt_Lin$Cell_Type), FUN=sum)
print(Cnt_Lin)
cols = c("#7B858A", "#FF00FF", "#F5F5F5", "#000000", "#3D4242","#DCDCDC") 
pie(Cnt_Lin$x, Cnt_Lin$Group.1, col = cols, border = "white", lty = 1,
    clockwise = TRUE, main = "Total cell")
dev.off()

#Plot IMMUNE pie
Cnt_Im <- aggregate(Cnt_Im$Count, 
                   by=list(Cnt_Im$Cell_Type), FUN=sum)
print(Cnt_Im)
cols = c("#FF8C00", "#00FF7F", "#ADFF2F", "#003366", "#1E90FF", "#FFFFFF", "#FF4500", "#FFCC66", "#66CCFF", "#663300") 
pie(Cnt_Im$x, Cnt_Im$Group.1, col = cols, border = "white", lty = 1, 
    clockwise = TRUE, main = "Total cell")
