# Get cell densities
# Author: Candace Liu
# Date: 2/3/21

library(data.table)
library(ggplot2)
library(RColorBrewer)
library(gridExtra)

case_dat = fread("gi/seg_cell_transformed_data_clusters_annot.csv")
ctrl_dat = fread("gi/ctrl/seg_cell_transformed_data_clusters_annot.csv")

case_area = fread("gi/tissue_area.csv")
ctrl_area = fread("gi/ctrl/tissue_area.csv")


## CASE
# Count / total # cells in each dataset
case_counts = case_dat[, .N, by=.(point,phenotype)]
case_total = table(case_dat$point)
case_counts[,total := unclass(unname(case_total[as.character(point)]))]
# Count immune
case_total_immune = case_dat[lineage=="CD45_cell",.N,by=point]
setnames(case_total_immune, "N", "total_immune")
case_counts = case_total_immune[case_counts, on=.(point)]
# Add area
case_counts = case_area[case_counts, on=.(point)]
# Density
case_counts[,density:=N/area_mm2]
case_counts[,dataset:="case"]

## CONTROL
# Count / total # cells in each dataset
ctrl_counts = ctrl_dat[, .N, by=.(point,phenotype)]
ctrl_total = table(ctrl_dat$point)
ctrl_counts[,total := unclass(unname(ctrl_total[as.character(point)]))]
# Count immune
ctrl_total_immune = ctrl_dat[lineage=="CD45_cell",.N,by=point]
setnames(ctrl_total_immune, "N", "total_immune")
ctrl_counts = ctrl_total_immune[ctrl_counts, on=.(point)]
# Add area
ctrl_counts = ctrl_area[ctrl_counts, on=.(point)]
# Density
ctrl_counts[,density:=N/area_mm2]
ctrl_counts[,dataset:="ctrl"]

## COMBINE DATA
all_counts = rbind(case_counts, ctrl_counts)
all_counts[phenotype == "NaKATPase_cell", phenotype := "PanCK_NaKATPase_cell"]
all_counts[phenotype == "PanCK_cell", phenotype := "PanCK_NaKATPase_cell"]


## ALL PHENOTYPES CSV
coln_order = c("dataset","point","area_pixels","area_mm2","total","total_immune","phenotype","N","density")
out_csv = all_counts[,..coln_order]
out_csv = out_csv[order(point)]
out_csv = out_csv[order(dataset)]
fwrite(out_csv, "cell_counts_density_bypheno.csv")

## ALL LINEAGES CSV
case_counts = case_dat[, .N, by=.(point,lineage)]
case_counts[,total := unclass(unname(case_total[as.character(point)]))]
case_counts = case_area[case_counts, on=.(point)]
case_counts[,dataset := "case"]
ctrl_counts = ctrl_dat[, .N, by=.(point,lineage)]
ctrl_counts[,total := unclass(unname(ctrl_total[as.character(point)]))]
ctrl_counts = ctrl_area[ctrl_counts, on=.(point)]
ctrl_counts[,dataset := "ctrl"]
all_lin = rbind(case_counts, ctrl_counts)
all_lin[,density:=N/area_mm2]
coln_order = c("dataset","point","area_pixels","area_mm2","total","lineage","N","density")
out_csv = all_lin[,..coln_order]
out_csv = out_csv[order(point)]
out_csv = out_csv[order(dataset)]
fwrite(out_csv, "cell_counts_density_bylin.csv")

## ALL COUNTS CSV
total_coln = c("dataset","point","area_mm2","total")
total_csv = unique(all_counts[,..total_coln])
total_csv[,density:=total/area_mm2]
total_csv = total_csv[order(point)]
total_csv = total_csv[order(dataset)]
fwrite(total_csv, "cell_counts_density_total.csv")




