# Compare cut-offs for determing positivity
# Author: Candace Liu
# Date: 2/3/21

library(data.table)
library(ggplot2)

marker = "IFNg"
delta_x = 0.01
cutoffs = seq(0.1,0.9,delta_x)

dat = fread("seg_cell_transformed_data_clusters_annot.csv")
all_counts = dat[,.N,by=.(phenotype)]
total = sum(all_counts$N)
all_counts[,all_freq:=N/total]

one_cut <- function(cut) {
  marker_dat = dat[,get(marker)]
  thresh = quantile(marker_dat[marker_dat>0],cut)
  pos = dat[get(marker) >= thresh]
  total_pos = nrow(pos)
  pos_count = pos[,.N,by=.(phenotype)]
  pos_count[,pos_freq:=N/total_pos]
 
  comb_dat = pos_count[,c("phenotype","pos_freq")][all_counts[,c("phenotype","all_freq")],on=.(phenotype)]
  comb_dat[,ratio:=pos_freq/all_freq]
  comb_dat[,cutoff:=cut]

  return(copy(comb_dat))
}


all_cut_dat = rbindlist(lapply(cutoffs, one_cut))
# Replace NAs
all_cut_dat[is.na(all_cut_dat)] = 0

# Plot
colors = fread("colors.csv")
pheno_to_label = colors$label
names(pheno_to_label) = colors$phenotype
label_to_color = colors$color
names(label_to_color) = colors$label

all_cut_dat[,pheno_label:=pheno_to_label[phenotype]]

ggplot(all_cut_dat, aes(x=cutoff, y=ratio, color=pheno_label)) +
  geom_line() +
  scale_color_manual(name="Phenotype",values=label_to_color) +
  ylab(paste0("% of ",marker,"+ out of all ",marker,"+ cells / % of cell type out of all cells"))
dev.off()


