# Determine cells that are positive for IFNg, Foxp3, and GranzB
# Author: Candace Liu
# Date: 2/3/21

library(data.table)
library(ggplot2)

dat = fread("seg_cell_transformed_data_clusters_annot.csv")
cut = 0.75

get_pos_cells <- function(marker, cut) {
  new_colname = paste0(marker,"_pos")
  marker_dat = dat[,get(marker)]
  thresh = quantile(marker_dat[marker_dat>0],cut)
  #thresh = cut*max(marker_dat)
  dat[,eval(new_colname) := get(marker) >= thresh]
}

get_pos_cells(marker="IFNg", cut)
get_pos_cells(marker="FoxP3", cut)
get_pos_cells(marker="GranzB", cut)
fwrite(dat, "seg_cell_transformed_data_clusters_annot_pos.csv")

## Plot IFNg+
colors = fread("colors.csv")
pheno_to_label = colors$label
names(pheno_to_label) = colors$phenotype
label_to_color = colors$color
names(label_to_color) = colors$label

pos_dat = dat[IFNg_pos == TRUE]
pos_dat$point = factor(pos_dat$point, levels=7:19)
pos_dat[,pheno_label:=pheno_to_label[phenotype]]
pos_dat[,lin_label:=pheno_to_label[lineage]]


# Lineage
pos_dat_no_other = pos_dat[lineage != "Other"]
count_lin = pos_dat_no_other[,.N,by=.(point,lin_label)]
pdf("IFNgpos_bar.pdf", height=8, width=10)
ggplot(count_lin, aes(fill=lin_label, y=N, x=point)) +
  geom_bar(position="stack",stat="identity",color="black") +
  scale_fill_manual(name="Lineage",values=label_to_color) +
  xlab("Point") +
  ylab("Count") +
  theme_bw()
ggplot(count_lin, aes(fill=lin_label, y=N, x=point)) +
  geom_bar(position="fill",stat="identity",color="black") +
  scale_fill_manual(name="Lineage",values=label_to_color) +
  xlab("Point") +
  ylab("Frequency") +
  theme_bw()

# Phenotype
count_pheno = pos_dat[,.N,by=.(point,pheno_label)]
ggplot(count_pheno, aes(fill=pheno_label, y=N, x=point)) +
  geom_bar(position="stack",stat="identity",color="black") +
  scale_fill_manual(name="Phenotype",values=label_to_color) +
  xlab("Point") +
  ylab("Count") +
  theme_bw()
ggplot(count_pheno, aes(fill=pheno_label, y=N, x=point)) +
  geom_bar(position="fill",stat="identity",color="black") +
  scale_fill_manual(name="Phenotype",values=label_to_color) +
  xlab("Point") +
  ylab("Frequency") +
  theme_bw()

dev.off()



