# Save TIFs with cell cluster IDs determined using FlowSOM
# Author: Candace Liu
# Date: 1/25/21

import pandas as pd
import numpy as np
import os
import matplotlib.pyplot as plt
from matplotlib import colors
from PIL import Image

clusters_path = "seg_cell_transformed_data_clusters_annot.csv"
clust_coln = "phenotype_num"
seg_dir = "segmentation_output"
output_dir = "overlays_segCellClusterIDs"
output_dir_colored = "overlays_segCellClusterIDs_colored"

# Make output directory
if not os.path.exists(output_dir):
    os.makedirs(output_dir)
if not os.path.exists(output_dir_colored):
    os.makedirs(output_dir_colored)

# Read data
clusters = pd.read_csv(clusters_path, sep=',')
points = np.unique(clusters['point'])
maxk = max(np.unique(clusters[clust_coln]))

# Manually define colors to match heatmaps
cols = [None]*59
cols[0] = '#FFFFFF'
cols[1] = '#FF9933'
cols[2] = '#00FFCC'
cols[3] = '#CCFF33'
cols[4] = '#666666'
cols[5] = '#003366'
cols[6] = '#3399FF'
cols[7] = '#FFFFFF'
cols[8] = '#FF3300'
cols[9] = '#FFCC66'
cols[10] = '#66CCFF'
cols[11] = '#663300'
cols[12] = '#ececec'
cols[13] = '#000000'
cols[14] = '#333333'
cols[15] = '#CCCCCC'

## Create custom cmap
mycols = cols[:maxk+1]
# Make bounds
bounds = [i-0.5 for i in np.linspace(0,maxk+1,maxk+2)]
colmap = colors.ListedColormap(mycols)
norm = colors.BoundaryNorm(bounds, colmap.N)

for point in points:  
    # Make dictionary of cell label:cluster id
    samp_clust = clusters.loc[clusters['point'] == point]
    clust_dict = dict(zip(samp_clust['label'],samp_clust[clust_coln]))

    # Get cell segmentation overlay
    label_array = np.array(Image.open(os.path.join(seg_dir, "Point"+str(point)+"_seg_labels.tif")))

    # Initialize array with 0s
    seg_cell_array = np.zeros(label_array.shape)
    # Assign labels
    for lab in clust_dict:
        idx = np.where(label_array == lab)
        seg_cell_array[idx] = clust_dict[lab]

    # Save overlay as TIF
    im = Image.fromarray(seg_cell_array.astype(np.int32))
    im.save(os.path.join(output_dir, "Point"+str(point)+"_segCellClusterIDs.tiff"))

    # Save colored overlay
    fig, ax = plt.subplots(figsize=(20,20))
    ax.imshow(seg_cell_array, cmap=colmap, norm=norm, origin="lower")
    ax.set_title("Point"+str(point))
    fig.tight_layout()
    plt.savefig(os.path.join(output_dir_colored, "Point"+str(point)+"_cellOverlay.tiff"))
    plt.close()


